package de.fraunhofer.iem.dataprovider.tool.enumeration

import de.fraunhofer.iem.dataprovider.kpi.enumeration.KpiKind
import de.fraunhofer.iem.dataprovider.tool.dto.FindingDto
import de.fraunhofer.iem.dataprovider.tool.dto.ToolResponseDto

enum class ToolType {
    ORT {
        override fun toViewModel(findings: List<FindingDto>): ToolResponseDto {
            return ToolResponseDto(
                name = this.getName(),
                findings = findings,
                relevantKpis = listOf(
                    KpiKind.MAXIMAL_VULNERABILITY.getName(),
                    KpiKind.VULNERABILITY_SCORE.getName(),
                    KpiKind.SECURITY.getName()
                ),
                description = "The OSS Review Toolkit (ORT) provides information about dependencies." +
                    "For more information see https://github.com/oss-review-toolkit/ort."
            )
        }

        override fun getName(): String {
            return "ORT"
        }
    },
    OCCMD {
        override fun toViewModel(findings: List<FindingDto>): ToolResponseDto {
            return ToolResponseDto(
                name = this.getName(),
                findings = findings,
                relevantKpis = listOf(
                    KpiKind.SECURITY.getName(),
                    KpiKind.PROCESS_TRANSPARENCY.getName(),
                    KpiKind.PROCESS_COMPLIANCE.getName(),
                    KpiKind.SECRETS.getName(),
                    KpiKind.COMMENTS_IN_CODE.getName(),
                    KpiKind.DOCUMENTATION.getName(),
                    KpiKind.SAST_USAGE.getName(),
                    KpiKind.CHECKED_IN_BINARIES.getName()
                ),
                description = "The OCCMD provides various information about the analyzed project." +
                    "For more information see https://gitlab.opencode.de/opencode-analyzer/occmd-public."
            )
        }

        override fun getName(): String {
            return "OCCMD"
        }
    },
    Gitlab {
        override fun toViewModel(findings: List<FindingDto>): ToolResponseDto {
            return ToolResponseDto(
                name = this.getName(),
                findings = findings,
                relevantKpis = listOf(
                    KpiKind.PROCESS_TRANSPARENCY.getName(),
                    KpiKind.PROCESS_COMPLIANCE.getName(),
                    KpiKind.NUMBER_OF_COMMITS.getName(),
                    KpiKind.NUMBER_OF_SIGNED_COMMITS.getName(),
                    KpiKind.DOCUMENTATION.getName(),
                ),
                description = "The Gitlab API is used to derive information about, e.g., the project's compliance" +
                    "to OpenCoDE's platform rules."
            )
        }

        override fun getName(): String {
            return "Gitlab API"
        }
    };

    abstract fun toViewModel(findings: List<FindingDto> = emptyList()): ToolResponseDto
    abstract fun getName(): String
}
